@@ -1,4 +1,4 @@
-# Copyright 2010-2014 MongoDB, Inc.
+# Copyright 2010-2015 MongoDB, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -28,6 +28,9 @@ class MaxKey(object):
     def __eq__(self, other):
         return isinstance(other, MaxKey)
 
+    def __hash__(self):
+        return hash(self._type_marker)
+
     def __ne__(self, other):
         return not self == other
 
